# TODO:   Building vignettes for R package
# 
# Author: Miguel Alvarez
################################################################################

library(devtools)

setwd("M:/WorkspaceR/taxlist")
build_vignettes()
